"""
:authors: 1Floppa3
:license: GPL-3.0 license, see LICENSE.md file
:copyright: (c) 2023 1Floppa3
"""

from .VideoUniquelizer import VideoUniquelizer

__author__ = '1Floppa3'
__version__ = '1.2.1'
__email__ = 'denis.kochetkov2006@gmail.com'